---
title: <span class="badge object-type-scalar"></span> NewtonMeters
---
# <span class="badge object-type-scalar"></span> NewtonMeters

Force: Newton-meters (Nm)

## Definition

```python
# Force: Newton-meters (Nm)
NewtonMeters: typing.Literal["forceNm"] = "forceNm"
```
